﻿--[[
****************************************************************************************

ARLText.lua

Text based output functions for all of AckisRecipeList

$Date: 2008-04-26 03:11:09 -0400 (Sat, 26 Apr 2008) $
$Rev: 71591 $

****************************************************************************************
]]--

local L			= LibStub("AceLocale-3.0"):GetLocale("AckisRecipeList")
local Crayon	= LibStub("LibCrayon-3.0")

--[[

	Non-gui output functions

]]--

-- Prints out to chat the recipe and where it can be found.

function ARL:PrintRecipeInfo(RecipeName)

	if (ARL.MissingRecipeListing[RecipeName]["Acquire"] ~= nil) then

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["MissingRecipePrefix"]) .. Crayon:Green(RecipeName .. " - [" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]") .. ARL.br .. ARL.MissingRecipeListing[RecipeName]["Acquire"])

	else

		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["MissingRecipePrefix"]) .. Crayon:Green(RecipeName .. " - [" .. ARL.MissingRecipeListing[RecipeName]["Level"] .. "]"))

	end

end

-- Identifies that a scan is occuring in chat

function ARL:InitiateScan(CurrentProfession, CurrentProfessionLevel, CurrentSpeciality)

	if (CurrentSpeciality == "") then

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Copper(ARL.ARLTitle))
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScan"]:format(CurrentProfession, CurrentProfessionLevel)))

	else

		-- Identify scan occuring in chat
		DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["InitiateScanSpecial"]:format(CurrentProfession, CurrentSpeciality, CurrentProfessionLevel)))
	
	end

end

-- Displays a summary of known recipes, total recipes and percentages.

function ARL:PrintRecipeListSummary()

	local NumMissingRecipes = ARL.NumberOfRecipes - ARL.FoundRecipes
	DEFAULT_CHAT_FRAME:AddMessage(Crayon:Purple(L["RecipeListSummary"]:format(ARL.FoundRecipes, ARL.NumberOfRecipes, math.floor(ARL.FoundRecipes / ARL.NumberOfRecipes * 100), NumMissingRecipes)))

end

-- Determines which recipes are known and which are not known, printing them out to the chat frame.

function ARL:DisplayRecipeResults(CurrentProfessionLevel, SortedList, CurrentProfession, CurrentSpeciality)

	-- Parse the ARL.MissingRecipeListing, printing out the entries
	if (ARL.MissingRecipeListing ~= nil) then

		-- No sorting at all
		if (SortedList == nil) then

			local RecipeName = next(ARL.MissingRecipeListing, nil)

			while (RecipeName ~= nil) do

				if (ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

					ARL:PrintRecipeInfo(RecipeName)

				end

				-- Move on to the next entry in the table
				RecipeName = next(ARL.MissingRecipeListing, RecipeName)
	
			end

		else

			for i, RecipeName in ipairs(SortedList) do

				if (ARL:CheckDisplayRecipe(RecipeName, CurrentProfessionLevel, CurrentProfession, CurrentSpeciality)) then

					ARL:PrintRecipeInfo(RecipeName)

				end

			end

		end

	end

	ARL:PrintRecipeListSummary()

end

--[[

	GUI text output functions

]]--

-- Prints out to chat a message stating that a current recipe is missing from the internal database.

function ARL:printMissingSkill(RecipeName)

	self:Print(Crayon:Red(RecipeName) .. Crayon:White(L["MissingFromDB"]))

end
